============
OeREB Client
============

|build status| |coverage report| |codacy report|


OEREB Client is a web application based on AngularJS, OpenLayers 3 and Bootstrap.

It is used as client application for the OEREB Server (pyramid_oereb_).

For detailed information, please refer to the documentation_.

.. _pyramid_oereb: https://github.com/openoereb/pyramid_oereb
.. _documentation: https://openoereb.github.io/oereb_client
.. |build status| image:: https://github.com/openoereb/oereb_client/workflows/CI/CD/badge.svg
   :target: https://github.com/openoereb/oereb_client/actions?query=workflow%3ACI%2FCD
.. |coverage report| image:: https://codecov.io/gh/openoereb/oereb_client/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/openoereb/oereb_client
.. |codacy report| image:: https://api.codacy.com/project/badge/Grade/df3da4ee9f1d4df690832e2dda1adde4
   :target: https://app.codacy.com/gh/openoereb/oereb_client?utm_source=github.com&utm_medium=referral&utm_content=openoereb/oereb_client&utm_campaign=Badge_Grade_Dashboard
